# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`ganeti`](#ganeti): Configure a drbd node server
* [`ganeti::nagios_checks`](#ganetinagios_checks): Deploy optional nagios check scripts for ganeti

_Private Classes_

* `ganeti::config`: Setup files and other resources for a ganeti node
* `ganeti::package`: Install packages required for a ganeti node
* `ganeti::service`: Make sure that the ganeti services are running.

## Classes

### ganeti

Configure a drbd node server

#### Parameters

The following parameters are available in the `ganeti` class.

##### `with_drbd`

Data type: `Boolean`

Set this to false to disable installing drbd on the node.

Default value: `true`

##### `security_model`

Data type: `Optional[Enum['pool']]`

If set to 'pool', will create a number of non-privileged users that ganeti
will use to run instances with. This is mostly useful when using the kvm
backend.

Default value: 'pool'

##### `pool_uid_base`

Data type: `Integer`

When security_model is set to 'pool', users that get created will start
with this uid and all additional ones will have uids incremented from this
number.

Default value: 4000

##### `pool_num_users`

Data type: `Integer`

When security_model is set to 'pool', number of users with sequential uids
that will get created for the pool.

Default value: 20

##### `pool_username_prefix`

Data type: `String[1]`

When security_model is set to 'pool', users that get created will have a
username that starts with this string. Names will then be completed with
the increment on the uid_base, starting at 0, appended to the prefix.

Default value: 'ganeti'

##### `private_ip`

Data type: `Optional[Stdlib::IP::Address]`

IP address configured on the node that is not facing a public network. It
is strongly recommended to configure nodes to have a second interface that
is part of a network that's not reachable through a public network. This
makes it possible to hide away ganeti commands, drbd replication traffic
and other sensitive information. This module will also configure ganeti
services to listen only to the private IP, if provided. See this post for
more information on how that can be configured:
https://groups.google.com/forum/#!searchin/ganeti/secondary$20ip|sort:date/ganeti/XBRWU7LwA6g/QnxpAo5HAQAJ

Default value: `undef`

##### `purge_instance_debootstrap`

Data type: `Boolean`

By default, this module removes all unknown configuration in the
ganeti-instance-debootstrap package creation template so that
instances created are using a known configuration. Set this value
to false in order to disable purging of the hooks directory.

Default value: `true`

##### `debootstrap_defaults`

Data type: `Ganeti::Debootstrap_config`

Set of configuration options that define the default behaviour for
instances created with ganeti-instance-debootstrap. The values in this hash
correspond to values in /etc/default/ganeti-instance-debootstrap. Refer to
`types/debootstrap_config.pp` to see all of the available options and their
expected data types.
- proxy: if set, configure apt to use a proxy when downloading packages
- mirror: URL of the debian apt source used to retrieve packages
- arch: if set, will install instances with a different architecture than
  the host
- suite: if set, define the default suite used by debootstrap
- extra_packages: list of packages to have debootstrap install on top of
  the requested suite
- components: if set, define the suite components used by debootstrap (e.g.
  "main,contrib,non-free")
- customize_dir: absolute path to a directory containing hooks run after
  debootstrap is done
- generate_cache: set to 'no' to disable package cache for debootstrap
- clean_cache: number of days during which packages are kept in cache
- partition_style: set to 'none' to avoid creating a partition table on
  devices joined to an instance
- partition_alignment: alignment of the partitions in sectors

Default value: {}

##### `debootstrap_variants`

Data type: `Hash[String, Ganeti::Variant]`

Hash of definitions for debootstrapt variants that are defined on the
cluster. Each value should be a struct with any of the required values set
(see the type alias Ganeti::Variant for a complete list of available
values). An empty list will create an empty configuration file, which
means that all default values will be used.

##### `debootstrap_puppet_hook`

Data type: `Boolean`

Set this to `true` to install puppet inside instances when they are
installed with instance-debootstrap. Make sure to also set
`debootstrap_puppet_server`.

Default value: `false`

##### `debootstrap_puppet_server`

Data type: `Optional[Stdlib::Host]`

Hostname or IP address of the puppet server to which the instances should
connect to. This value is only used when debootstrap_puppet_hook is set to
`true`.

Default value: `undef`

##### `debootstrap_locale`

Data type: `Optional[String[1]]`

Name of the default locale that will be configured in the new instances
when they get created by the debootstrap template. If set to undef
(default), locale will be untouched and no hook script for setting the
locale will be installed. This should be something legal in the
`locales` package, for example en_US or en_US.UTF-8, as
(currently) defined in /var/lib/dpkg/info/locales.config.

Default value: `undef`

##### `debootstrap_charmap`

Data type: `String[1]`

Name of the character map (should correspond to the name of a file in
/usr/share/i18n/charmaps) used by the default locale configured in new
instances. This value is unused if debootstrap_locale is set to undef.

Default value: 'UTF-8'

### ganeti::nagios_checks

If you include this class, make sure to order it after install of
nagios-plugins-basic. Otherwise, the plugin directory will not exist.

